==> qtjambi-qt3drender-5.15.4-sources.jar: io/qt/qt3d/render/QTexture2DMultisampleArray.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target2DMultisampleArray target format</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisamplearray.html">Qt3DRender::QTexture2DMultisampleArray</a></p>
 */
public class QTexture2DMultisampleArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DMultisampleArray.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DMultisampleArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DMultisampleArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisamplearray.html#QTexture2DMultisampleArray">Qt3DRender::QTexture2DMultisampleArray::QTexture2DMultisampleArray(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DMultisampleArray(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DMultisampleArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisampleArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisampleArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture2DMultisampleArray instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QTexture2DMultisampleArray.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target2DMultisampleArray target format</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisamplearray.html">Qt3DRender::QTexture2DMultisampleArray</a></p>
 */
public class QTexture2DMultisampleArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DMultisampleArray.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DMultisampleArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DMultisampleArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisamplearray.html#QTexture2DMultisampleArray">Qt3DRender::QTexture2DMultisampleArray::QTexture2DMultisampleArray(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DMultisampleArray(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DMultisampleArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisampleArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisampleArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture2DMultisampleArray instance, QDeclarativeConstructor constructor);
    
}
